/* Copyright (C) 2009, 2010, 2011 Keith Crane

This file is part DFILE Tools.

DFILE Tools is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or (at
your option) any later version.

DFILE Tools is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with DFILE Tools; see the file COPYING.  If not, see
<http://www.gnu.org/licenses/>. */

#include <stdlib.h>
#include "tbox.h"
#include "dfile.h"
#include "where.h"


const char *Where_err_msg[] = {

/* WHERE_NOERR */	"no error",
/* WHERE_SYNTAX */	"syntax error",
/* WHERE_UNKNVAR */	"unknown variable encountered",
/* WHERE_INVLDNBR */	"failed to convert ASCII value to number",
/* WHERE_REGEX */	"failed to compile regular expression",
/* WHERE_HASHFAIL */	"hash algorithm inadequate for IN values"

};

const size_t Where_err_msg_cnt = sizeof( Where_err_msg ) / sizeof( char * );
